@@ -134,7 +134,7 @@ class DocumentNotFoundError(__InvalidRequestError):
     status_code = HTTPStatus.NOT_FOUND
 
 
-class NonNeuralIndexError(__InvalidRequestError):
+class NonTensorIndexError(__InvalidRequestError):
     """Error trying to use a non-neural OpenSearch index like a neural one"""
     code = "document_not_found"
     status_code = HTTPStatus.NOT_FOUND
